/*
  Formalize - version 1.2 (http://formalize.me - modified to add support for custom select box behavior) 
  See: michael.warren@capitalone.com / kmudrick@ingdirect.com 

  Note: This file depends on the jQuery library.
*/

// Module pattern:
// http://yuiblog.com/blog/2007/06/12/module-pattern
var FORMALIZE = (function($, window, document, undefined) {
  // Internet Explorer detection.
  function IE(version) {
    var b = document.createElement('b');
    b.innerHTML = '<!--[if IE ' + version + ']><br><![endif]-->';
    return !!b.getElementsByTagName('br').length;
  }

  // Private constants.
  var PLACEHOLDER_SUPPORTED = 'placeholder' in document.createElement('input');
  var AUTOFOCUS_SUPPORTED = 'autofocus' in document.createElement('input');
  var IE6 = IE(6);
  var IE7 = IE(7);

  // Expose innards of FORMALIZE.
  return {
    // FORMALIZE.go
    go: function() {
      var i, j = this.init;

      for (i in j) {
        j.hasOwnProperty(i) && j[i]();
      }
      
      $("select").on({
          "mouseenter focus":function(){
              $(this).next(".selectSpan").children(".selectSpanArrow").addClass("hover");
          },
          "mouseleave focusout":function(){
              $(this).next(".selectSpan").children(".selectSpanArrow").removeClass("hover");
          }
      });
      
      // Add/remove the "focused" class on buttons when focusing
      $("button, input[type=reset], input[type=submit], input[type=button]").on({
          "focus" : function() {
              $(this).addClass("focused");
          },
          "focusout" : function() {
              $(this).removeClass("focused");
          }
      });
      
    },
    // FORMALIZE.init
    init: {
      customSelect: function() {
          if(!$.browser.msie || ($.browser.msie&&$.browser.version>6)){
              return $("select").each(function() {
                  if( $(this).next(".selectSpan").length > 0 ){
                      $(this).next(".selectSpan").remove();
                  }

                  var currentSelected = $(this).find(':selected');
                  var html = currentSelected.html();
                  if(!html){ html='&nbsp;'; }

                  $(this).after('<span class="selectSpan"><span class="selectSpanArrow"></span><span class="selectSpanInner">'+html+'</span></span>').css({position:'absolute', opacity:0,fontSize:$(this).next("span").css('font-size')});
	  
                  var selectBoxSpan = $(this).next(".selectSpan");

                  var selectBoxWidth = parseInt($(this).outerWidth()) - parseInt(selectBoxSpan.css('padding-left')) -parseInt(selectBoxSpan.css('padding-right'));
                  var selectBoxSpanInner = selectBoxSpan.find('.selectSpanInner');
      
                  selectBoxSpan.css({width: parseInt($(this).width()), display:'inline-block'});
                  selectBoxSpanInner.css({width:parseInt($(this).width()) - parseInt(selectBoxSpanInner.css('padding-left')) -parseInt(selectBoxSpanInner.css('padding-right')), display:'inline-block'});
                  var selectBoxHeight = parseInt(selectBoxSpan.height()) + parseInt(selectBoxSpan.css('padding-top')) + parseInt(selectBoxSpan.css('padding-bottom'));
                  $(this).height(selectBoxHeight).on("change keypress", function(){
                      selectBoxSpanInner.text($(this).find(':selected').text()).parent().addClass('changed');
                  });
      
              });
          }
      },
      // FORMALIZE.init.full_input_size
      full_input_size: function() {
        if (!IE7 || !$('textarea, input.input_full').length) {
          return;
        }

        // This fixes width: 100% on <textarea> and class="input_full".
        // It ensures that form elements don't go wider than container.
        $('textarea, input.input_full').wrap('<span class="input_full_wrap"></span>');
      },
      // FORMALIZE.init.ie6_skin_inputs
      ie6_skin_inputs: function() {
        // Test for Internet Explorer 6.
        if (!IE6 || !$('input, select, textarea').length) {
          // Exit if the browser is not IE6,
          // or if no form elements exist.
          return;
        }

        // For <input type="submit" />, etc.
        var button_regex = /button|submit|reset/;

        // For <input type="text" />, etc.
        var type_regex = /date|datetime|datetime-local|email|month|number|password|range|search|tel|text|time|url|week/;

        $('input').each(function() {
          var el = $(this);

          // Is it a button?
          if (this.getAttribute('type').match(button_regex)) {
            el.addClass('ie6_button');

            /* Is it disabled? */
            if (this.disabled) {
              el.addClass('ie6_button_disabled');
            }
          }
          // Or is it a textual input?
          else if (this.getAttribute('type').match(type_regex)) {
            el.addClass('ie6_input');

            /* Is it disabled? */
            if (this.disabled) {
              el.addClass('ie6_input_disabled');
            }
          }
        });

        $('textarea, select').each(function() {
          /* Is it disabled? */
          if (this.disabled) {
            $(this).addClass('ie6_input_disabled');
          }
        });
      },
      // FORMALIZE.init.autofocus
      autofocus: function() {
        if (AUTOFOCUS_SUPPORTED || !$(':input[autofocus]').length) {
          return;
        }

        $(':input[autofocus]:visible:first').focus();
      }
    }
  };
// Alias jQuery, window, document.
})(jQuery, this, this.document);

// Automatically calls all functions in FORMALIZE.init
jQuery(document).ready(function() {

  FORMALIZE.go();
  
  $("select").on({
	  mouseenter:function(){

	  $(this).next(".selectSpan").children(".selectSpanArrow").addClass("hover");
	  },
	  mouseleave:function(){

	  $(this).next(".selectSpan").children(".selectSpanArrow").removeClass("hover");
	  },

	  focus:function(){

	  $(this).next(".selectSpan").children(".selectSpanInner").addClass("hover");
	  },

	  focusout:function(){

	  $(this).next(".selectSpan").children(".selectSpanInner").removeClass("hover");
	  }

  });


});